# What is it?

> A wrapper of the api logic used to interact with blue_media.


# Why is it needed?

> I just wanted to do it, no why.

# How to use it?

**Installing the library**
> pip install blue_media

**Importing the library**
> from blue_media import BlueClass

**Initialize the Config Class**
> config = Config(**kwargs)

**Initialize the BlueMedia Class**
> blue = BlueMedia(config)

**Call the GET and POST methods**

> blue.async_get(**kwargs)
> blue.async_post(**kwargs)

By: "_"
